from github import Auth, Github
import base64
import os
import logging

logging.basicConfig(
    format="%(asctime)s - %(levelname)s - [%(filename)s:%(lineno)d] - %(message)s",
    datefmt="%Y-%m-%d %H:%M:%S",
    level=logging.INFO,
)


class GitHubConnection:
    def __init__(self):
        self.server_url = os.environ.get(
            "GITHUB_SERVER", "https://github.gwd.broadcom.net"
        )
        self.client_id = os.environ.get("APP_CLIENT_ID", 430)
        self.installation_id = os.environ.get("APP_INSTALLATION_ID", 809)
        self.private_key = base64.b64decode(
            os.environ.get("PRIVATE_KEY_B64", "")
        ).decode()

    def get_token(self):
        logging.info(
            f"Generating token for app id: {self.client_id} and installation id: {self.installation_id}"
        )

        auth = Auth.AppAuth(self.client_id, self.private_key).get_installation_auth(
            self.installation_id
        )
        github = Github(auth=auth, base_url=f"{self.server_url}/api/v3")

        return auth.token

    def connect(self):
        logging.info("Logging using the generated token")

        token = self.get_token()
        auth = Auth.Token(token)

        return Github(auth=auth, base_url=f"{self.server_url}/api/v3")
